@@ -697,6 +697,7 @@ void checkresources(void)
             } else {
                 printf("%-40s", list1->string);
                 if(0
+#if 0
                     || !strcmp(list1->string, "FFMPEGFormat")
                     || !strcmp(list1->string, "FFMPEGAudioBitrate")
                     || !strcmp(list1->string, "FFMPEGVideoBitrate")
@@ -706,6 +707,7 @@ void checkresources(void)
                   ) {
                     printf("(FFMPEG only, might be disabled)");
                 } else if(0
+#endif
                     || !strcmp(list1->string, "MIDIEnable")
                     || !strcmp(list1->string, "MIDIMode")
                     || !strcmp(list1->string, "MIDIInDev")
@@ -791,22 +793,32 @@ void checkresources(void)
                     || !strcmp(list1->string, "CrtcFullscreenDevice")
                     || !strcmp(list1->string, "CrtcFullscreen")
                     || !strcmp(list1->string, "CrtcFullscreenStatusbar")
+                    || !strcmp(list1->string, "CrtcFullscreenCustomWidth")
+                    || !strcmp(list1->string, "CrtcFullscreenCustomHeight")
                     || !strcmp(list1->string, "TEDFullscreenMode")
                     || !strcmp(list1->string, "TEDFullscreenDevice")
                     || !strcmp(list1->string, "TEDFullscreen")
                     || !strcmp(list1->string, "TEDFullscreenStatusbar")
+                    || !strcmp(list1->string, "TEDFullscreenCustomWidth")
+                    || !strcmp(list1->string, "TEDFullscreenCustomHeight")
                     || !strcmp(list1->string, "VDCFullscreenMode")
                     || !strcmp(list1->string, "VDCFullscreenDevice")
                     || !strcmp(list1->string, "VDCFullscreen")
                     || !strcmp(list1->string, "VDCFullscreenStatusbar")
+                    || !strcmp(list1->string, "VDCFullscreenCustomWidth")
+                    || !strcmp(list1->string, "VDCFullscreenCustomHeight")
                     || !strcmp(list1->string, "VICFullscreenMode")
                     || !strcmp(list1->string, "VICFullscreenDevice")
                     || !strcmp(list1->string, "VICFullscreen")
                     || !strcmp(list1->string, "VICFullscreenStatusbar")
+                    || !strcmp(list1->string, "VICFullscreenCustomWidth")
+                    || !strcmp(list1->string, "VICFullscreenCustomHeight")
                     || !strcmp(list1->string, "VICIIFullscreenMode")
                     || !strcmp(list1->string, "VICIIFullscreenDevice")
                     || !strcmp(list1->string, "VICIIFullscreen")
                     || !strcmp(list1->string, "VICIIFullscreenStatusbar")
+                    || !strcmp(list1->string, "VICIIFullscreenCustomWidth")
+                    || !strcmp(list1->string, "VICIIFullscreenCustomHeight")
 
                   ) {
                     printf("(SDL only, not GTK3)");
@@ -1075,11 +1087,17 @@ void checkoptions(void)
                 else printf("  ");
                 printf("%-40s", list1->string);
                 if(0
+#if 0
                     || !strcmp(list1->string, "-ffmpegaudiobitrate")
                     || !strcmp(list1->string, "-ffmpegvideobitrate")
                   ) {
                     printf("(FFMPEG only, might be disabled)");
                 } else if(0
+#endif
+               || !strcmp(list1->string, "-no-redirect-streams")
+                  ) {
+                    printf("(Windows only)");
+                } else if(0
                     || !strcmp(list1->string, "-miditype")
                     || !strcmp(list1->string, "-midi")
                     || !strcmp(list1->string, "+midi")
@@ -1189,6 +1207,16 @@ void checkoptions(void)
                     || !strcmp(list1->string, "-VDCfullmode")
                     || !strcmp(list1->string, "-VICfullmode")
                     || !strcmp(list1->string, "-VICIIfullmode")
+                    || !strcmp(list1->string, "-Crtcfullwidth")
+                    || !strcmp(list1->string, "-TEDfullwidth")
+                    || !strcmp(list1->string, "-VDCfullwidth")
+                    || !strcmp(list1->string, "-VICfullwidth")
+                    || !strcmp(list1->string, "-VICIIfullwidth")
+                    || !strcmp(list1->string, "-Crtcfullheight")
+                    || !strcmp(list1->string, "-TEDfullheight")
+                    || !strcmp(list1->string, "-VDCfullheight")
+                    || !strcmp(list1->string, "-VICfullheight")
+                    || !strcmp(list1->string, "-VICIIfullheight")
                   ) {
                     printf("(SDL only, not GTK3)");
                 } else if(0
