@@ -37,7 +37,6 @@
 #include "sampler.h"
 #include "ui.h"
 #include "uimachinewindow.h"
-#include "settings_sampler.h"
 #include "vicii.h"
 #include "videomodelwidget.h"
 #include "widgethelpers.h"
@@ -47,24 +46,9 @@
 #include "clockport.h"
 
 #include "reu.h"
-#include "reuwidget.h"
 #include "cartridge.h"
-#include "ramcartwidget.h"
-#include "dqbbwidget.h"
-#include "expertwidget.h"
-#include "isepicwidget.h"
-#include "gmod2widget.h"
-#include "gmod3widget.h"
-#include "mmcrwidget.h"
-#include "mmc64widget.h"
-#include "retroreplaywidget.h"
-#include "easyflashwidget.h"
-#include "rrnetmk3widget.h"
-#include "uicart.h"
-#include "carthelpers.h"
 #include "machine.h"
 #include "tapecart.h"
-#include "tapeportdeviceswidget.h"
 #include "crtpreviewwidget.h"
 
 #include "c64ui.h"
@@ -151,41 +135,9 @@ int c64ui_init(void)
     video_model_widget_set_resource("MachineVideoStandard");
     video_model_widget_set_models(c64_vicii_models);
 
-    settings_sampler_set_devices_getter(sampler_get_devices);
-
-    /* work around VSID again */
-    clockport_device_widget_set_devices((void *)clockport_supported_devices);
-
-    /* I/O extension function pointers */
-    carthelpers_set_functions(
-            cartridge_save_image,
-            cartridge_flush_image,
-            cartridge_type_enabled,
-            cartridge_enable,
-            cartridge_disable,
-            cartridge_can_save_image,
-            cartridge_can_flush_image,
-            cartridge_set_default,
-            cartridge_unset_default,
-            cartridge_get_info_list);
-
-    /* ui_cart_set_detect_func(cartridge_detect); only cbm2/plus4 */
-    ui_cart_set_list_func(cartridge_get_info_list);
-    ui_cart_set_attach_func(cartridge_attach_image);
-    ui_cart_set_freeze_func(cartridge_trigger_freeze);
-    ui_cart_set_detach_func(cartridge_detach_image);
-    ui_cart_set_set_default_func(cartridge_set_default);
-    ui_cart_set_unset_default_func(cartridge_unset_default);
-
-    /* set tapecart flush function */
-    tapeport_devices_widget_set_tapecart_flush_func(tapecart_flush_tcrt);
-
     /* set C64 model_get function */
     settings_model_widget_set_model_func(c64model_get);
 
-    /* crt preview widget functions */
-    crt_preview_widget_set_open_func(crt_open);
-    crt_preview_widget_set_chip_func(crt_read_chip_header);
     return 0;
 }
 
