@@ -50,6 +50,8 @@ void kbd_arch_shutdown(void);
 void kbd_initialize_numpad_joykeys(int *joykeys);
 void kbd_connect_handlers(GtkWidget *widget, void *data);
 
+/** \brief  Prefix for the Gtk3 port keymap files
+ */
 #define KBD_PORT_PREFIX "gtk3"
 
 /* add more function prototypes as needed below */
@@ -57,9 +59,10 @@ void kbd_connect_handlers(GtkWidget *widget, void *data);
 signed long kbd_arch_keyname_to_keynum(char *keyname);
 const char *kbd_arch_keynum_to_keyname(signed long keynum);
 
-void kbd_hotkey_init(void);
-void kbd_hotkey_shutdown(void);
-gboolean kbd_hotkey_add(guint code, guint mask, void (*callback)(void));
-gboolean kbd_hotkey_add_list(kbd_gtk3_hotkey_t *list);
+/** \brief  Only here for c1541-stubs.c, not used in the Gtk3 UI */
+/**
+ *  \return NULL
+ */
+const char *kbd_get_menu_keyname(void);
 
 #endif
