@@ -136,10 +136,19 @@ done
 if test x"$CROSS" != "xtrue"; then
 
 # The following lines assume that this script is run by MSYS2.
+  curdir=`pwd`
   cp `ntldd -R $BUILDPATH/bin/x64sc.exe|gawk '/\\\\bin\\\\/{print $3;}'|cygpath -f -` $BUILDPATH/bin
   cd $MINGW_PREFIX
   cp bin/lib{lzma-5,rsvg-2-2,xml2-2}.dll $BUILDPATH/bin
-  cp --parents lib/gdk-pixbuf-2.0/2.*/loaders.cache lib/gdk-pixbuf-2.0/2.*/loaders/libpixbufloader-{png,svg,xpm}.dll $BUILDPATH
+  cp --parents lib/gdk-pixbuf-2.0/2.10.0/loaders/*pixbufloader*{png,svg,xpm}.dll $BUILDPATH
+  # generate loaders.cache from the copied loaders in the binidst, not the system loaders
+  cd $BUILDPATH
+  GDK_PIXBUF_MODULEDIR=lib/gdk-pixbuf-2.0/2.10.0/loaders gdk-pixbuf-query-loaders > lib/gdk-pixbuf-2.0/2.10.0/loaders.cache
+  cd $MINGW_PREFIX
+  # get dependencies of the SVG loader
+  # FIXME: only works for the updated SVG (renamed) SVG loader
+  cp `ntldd -R $BUILDPATH/lib/gdk-pixbuf-2.0/2.10.0//loaders/pixbufloader_svg.dll | gawk '/\\\\bin\\\\/{print $3;}' | cygpath -f -` $BUILDPATH/bin
+
   # GTK3 accepts having only scalable icons,
   # which reduces the bindist size considerably.
   cp --parents -a share/icons/Adwaita/{index.*,scalable,symbolic} $BUILDPATH
@@ -154,6 +163,8 @@ if test x"$CROSS" != "xtrue"; then
     cp `ntldd -R $UNZIPBIN | gawk '/\\\\bin\\\\/{print $3;}' | cygpath -f -` $BUILDPATH/bin
   fi
 
+  cd "$curdir"
+
 else
 
 # The following lines assume a cross compiler,
@@ -230,6 +241,10 @@ EOF
 
 fi
 
+
+echo "TOPSRCDIR = $TOPSRCDIR"
+echo "BUILDPATH = $BUILDPATH"
+
 cp -a $TOPSRCDIR/data/C128 $TOPSRCDIR/data/C64 $BUILDPATH
 cp -a $TOPSRCDIR/data/C64DTV $TOPSRCDIR/data/CBM-II $BUILDPATH
 cp -a $TOPSRCDIR/data/DRIVES $TOPSRCDIR/data/PET $BUILDPATH
@@ -240,7 +255,7 @@ rm -f `find $BUILDPATH -name "sdl_*"`
 mkdir $BUILDPATH/common
 mkdir $BUILDPATH/hotkeys
 cp $TOPBUILDDIR/data/common/vice.gresource $BUILDPATH/common
-cp $TOPSRCDIR/data/common/C64_Pro_Mono-STYLE.ttf $BUILDPATH/common
+cp $TOPSRCDIR/data/common/*.ttf $BUILDPATH/common
 cp $TOPSRCDIR/data/hotkeys/*.vhk $BUILDPATH/hotkeys
 
 #if test x"$HTML_DOCS" = "xyes"; then
