@@ -5,7 +5,7 @@
  * \author  Bas Wassink <b.wassink@ziggo.nl>
  * \author  Marcus Sutton <loggedoubt@gmail.com>
  *
- * $VICERES AutostartOnDoubleclick  all
+ * $VICERES AutostartOnDoubleClick  all
  * $VICERES CrtcFullscreen          xcbm2 xpet
  * $VICERES TEDFullscreen           xplus4
  * $VICERES VDCFullscreen           x128
@@ -94,11 +94,9 @@
 #include "mainlock.h"
 #include "mixerwidget.h"
 #include "monitor.h"
-#ifdef HAVE_DEBUG_GTK3UI
-#include "rommanager.h"
-#endif
 #include "resources.h"
 #include "settings_keyboard.h"
+#include "settings_rom.h"
 #include "types.h"
 #include "uiactions.h"
 #include "uiapi.h"
@@ -183,11 +181,11 @@ static void ui_action_dispatch(ui_action_map_t *);
  * mime-types.
  */
 GtkTargetEntry ui_drag_targets[UI_DRAG_TARGETS_COUNT] = {
-    { "text/plain",     0, DT_TEXT },   /* we get this on at least my Linux
-                                           box with Mate */
-    { "text/uri",       0, DT_URI },
-    { "text/uri-list",  0, DT_URI_LIST }    /* we get this using Windows
-                                               Explorer or macOS Finder */
+    { "text/plain",     0, DT_TEXT_PLAIN    },  /* we get this on at least my
+                                                   Linux box with Mate */
+    { "text/uri",       0, DT_TEXT_URI      },  /* not yet encountered */
+    { "text/uri-list",  0, DT_TEXT_URI_LIST }   /* we get this using Windows
+                                                   Explorer or macOS Finder */
 };
 
 
@@ -264,9 +262,11 @@ enum {
  */
 static const resource_string_t resources_string[] = {
     /* VTE-monitor font */
-    { "MonitorFont", "monospace 11", RES_EVENT_NO, NULL,
+    /* { "MonitorFont", "Mono 11", RES_EVENT_NO, NULL, */
+    { "MonitorFont", "C64 Pro Mono Regular 9", RES_EVENT_NO, NULL,
         &ui_resources.monitor_font, set_monitor_font, NULL },
-    { "MonitorFG", "#ffffff", RES_EVENT_NO, NULL,
+    /* we want this one to be "terminal white" but NOT "bright white" */
+    { "MonitorFG", "#cccccc", RES_EVENT_NO, NULL,
         &ui_resources.monitor_fg, set_monitor_fg, NULL },
     { "MonitorBG", "#000000", RES_EVENT_NO, NULL,
         &ui_resources.monitor_bg, set_monitor_bg, NULL },
@@ -295,7 +295,7 @@ static const resource_int_t resources_int_shared[] = {
     { "PauseOnSettings", 0, RES_EVENT_NO, NULL,
         &ui_resources.pause_on_settings, set_pause_on_settings, NULL },
     /* Use autostart on doubleclick in dialogs */
-    { "AutostartOnDoubleclick", 0, RES_EVENT_NO, NULL,
+    { "AutostartOnDoubleClick", 0, RES_EVENT_NO, NULL,
         &ui_resources.autostart_on_doubleclick, set_autostart_on_doubleclick,
         NULL },
 
@@ -414,10 +414,10 @@ static const cmdline_option_t cmdline_options_common[] =
         set_monitor_fg,  NULL, "MonitorFG", NULL,
         "font-foreground", "Set monitor font foreround color" },
     { "-autostart-on-doubleclick", SET_RESOURCE, CMDLINE_ATTRIB_NONE,
-        NULL, NULL, "AutostartOnDoubleclick", (void*)1,
+        NULL, NULL, "AutostartOnDoubleClick", (void*)1,
         NULL, "Autostart files on doubleclick" },
     { "+autostart-on-doubleclick", SET_RESOURCE, CMDLINE_ATTRIB_NONE,
-        NULL, NULL, "AutostartOnDoubleclick", (void*)0,
+        NULL, NULL, "AutostartOnDoubleClick", (void*)0,
         NULL, "Open files on doubleclick" },
     { "-settings-node", CALL_FUNCTION, CMDLINE_ATTRIB_NEED_ARGS,
         set_settings_node_path, NULL, NULL, NULL,
@@ -825,6 +825,57 @@ static gboolean on_drag_drop(GtkWidget *widget,
     return TRUE;
 }
 
+/** \brief  Extract filename from drag data
+ *
+ * \param[in]   data    drag data from dropping media onto the emulator window
+ * \param[in]   info    drag target mime type info
+ *
+ * \return  filename or \c NULL
+ * \note    the filename should be freed with \c g_free() after use
+ *
+ * \todo    Perhaps make public, VSID uses duplicate code.
+ */
+static gchar *drag_data_get_filename(GtkSelectionData *data,
+                                     guint             info)
+{
+    guchar  *text;
+    gchar  **uri_list = NULL;
+    gchar   *filename = NULL;
+
+    switch (info) {
+
+        case DT_TEXT_URI_LIST:  /* 'text/uri-list */
+            /* Windows and MacOS */
+            uri_list = gtk_selection_data_get_uris(data);
+           break;
+
+        case DT_TEXT_PLAIN:     /* 'text/plain' */
+            /* Qt- and Gtk-based WM's on Linux */
+            text = gtk_selection_data_get_text(data);
+            /* text contains newline-separated lines of 'file://' URIs and a
+             * trailing newline */
+            g_strchomp((gchar *)text);
+            uri_list = g_strsplit((const gchar *)text, "\n", -1);
+            g_free(text);
+            break;
+
+        case DT_TEXT_URI:       /* fall through ('text/uri') */
+        default:
+            log_error(LOG_DEFAULT, "Unhandled drag target %u", info);
+            break;
+    }
+
+    if (uri_list != NULL) {
+        if (uri_list[0] != NULL) {
+            /* grab first URI in list */
+            filename = g_filename_from_uri(uri_list[0], NULL, NULL);
+        }
+        g_strfreev(uri_list);
+    }
+
+    return filename;
+}
+
 /** \brief  Handler for the 'drag-data-received' event
  *
  * Autostarts an image/prg when valid. Please note that VSID now has its own
@@ -838,109 +889,51 @@ static gboolean on_drag_drop(GtkWidget *widget,
  * \param[in]   info        int declared in the targets array (unclear)
  * \param[in]   time        no idea
  */
-static void on_drag_data_received(GtkWidget *widget,
-                                  GdkDragContext *context,
-                                  gint x,
-                                  gint y,
+static void on_drag_data_received(GtkWidget        *widget,
+                                  GdkDragContext   *context,
+                                  gint              x,
+                                  gint              y,
                                   GtkSelectionData *data,
-                                  guint info,
-                                  guint time)
+                                  guint             info,
+                                  guint             time)
 {
-    gchar **uris;
-    gchar *filename = NULL;
-    gchar **files = NULL;
-    guchar *text = NULL;
-    GdkDragAction action = gdk_drag_context_get_selected_action (context);
+    gchar *filename = drag_data_get_filename(data, info);
 
-    switch (info) {
-
-        case DT_URI_LIST:
-            /*
-             * This branch appears to be taken on both Windows and macOS.
-             */
-
-            /* got possible list of URI's */
-            uris = gtk_selection_data_get_uris(data);
-            if (uris != NULL) {
-                /* keep this debugging output, drag'n'drop is pretty flaky */
-#if 0
-                /* dump URI's on stdout */
-                debug_gtk3("got URI's:");
-                for (i = 0; uris[i] != NULL; i++) {
-
-                    debug_gtk3("URI: '%s'\n", uris[i]);
-                    filename = g_filename_from_uri(uris[i], NULL, NULL);
-                    debug_gtk3("filename: '%s'.", filename);
-                    if (filename != NULL) {
-                        g_free(filename);
-                    }
-                }
-#endif
-
-                /* use the first/only entry as the autostart file
-                 *
-                 * XXX: perhaps add any additional files to the fliplist
-                 *      if Dxx?
-                 */
-                if (uris[0] != NULL) {
-                    filename = g_filename_from_uri(uris[0], NULL, NULL);
-                } else {
-                    filename = NULL;
-                }
-
-                g_strfreev(uris);
-            }
-            break;
-
-        case DT_TEXT:
-            /*
-             * this branch appears to be taken on both Gtk and Qt based WM's
-             * on Linux
-             */
-
-
-            /* text will contain a newline separated list of 'file://' URIs,
-             * and a trailing newline */
-            text = gtk_selection_data_get_text(data);
-            /* remove trailing whitespace */
-            g_strchomp((gchar *)text);
-
-            files = g_strsplit((const gchar *)text, "\n", -1);
-            g_free(text);
-
-#if 0
-# ifdef HAVE_DEBUG_GTK3UI
-            for (i = 0; files[i] != NULL; i++) {
-                /* keep this as well */
-                gchar *tmp = g_filename_from_uri(files[i], NULL, NULL);
-                debug_gtk3("URI: '%s', filename: '%s'.",
-                        files[i], tmp);
-            }
-# endif
-#endif
-            /* now grab the first file */
-            filename = g_filename_from_uri(files[0], NULL, NULL);
-            g_strfreev(files);
-            break;
-
-        default:
-            filename = NULL;
-            break;
-    }
-
-    /* can we attempt autostart? */
     if (filename != NULL) {
-        if (action != GDK_ACTION_MOVE) {
-            /* drop with alt ("link") -> only load, not run */
-            int mode = (action == GDK_ACTION_LINK) ? AUTOSTART_MODE_LOAD : AUTOSTART_MODE_RUN;
-            if (autostart_autodetect(filename, NULL, 0, mode) != 0) {
-                /* TODO: add proper UI error */
-            }
-        } else {
-            /* drop with shift ("move") -> only mount the disk */
-            if (file_system_attach_disk(8, 0, filename) < 0) {
-                /* TODO: add proper UI error */
-            }
+        GdkDragAction action;
+        int           drop_mode = 0;
+
+        action = gdk_drag_context_get_selected_action(context);
+
+        /* determine autostart behaviour */
+        switch (action) {
+            case GDK_ACTION_COPY: /* fall through */
+            default:
+                /* no modifier key held, use the resource value */
+                resources_get_int("AutostartDropMode", &drop_mode);
+                break;
+            case GDK_ACTION_MOVE:
+                /* Shift ("move"): attach image */
+                drop_mode = AUTOSTART_DROP_MODE_ATTACH;
+                break;
+            case GDK_ACTION_LINK:
+                /* Alt ("link"): attach and load  */
+                drop_mode = AUTOSTART_DROP_MODE_LOAD;
+                break;
+        }
+
+        switch (drop_mode) {
+            case AUTOSTART_DROP_MODE_ATTACH:
+                file_system_attach_disk(8, 0, filename);
+                break;
+            case AUTOSTART_DROP_MODE_LOAD:
+                autostart_autodetect(filename, NULL, 0, AUTOSTART_MODE_LOAD);
+                break;
+            case AUTOSTART_DROP_MODE_RUN:
+                autostart_autodetect(filename, NULL, 0, AUTOSTART_MODE_RUN);
+                break;
+            default:
+                break;
         }
         g_free(filename);
     }
@@ -983,7 +976,7 @@ static gboolean on_focus_in_event(GtkWidget *widget, GdkEventFocus *event,
 
     if (index < 0) {
         /* We should never end up here. */
-        log_error(LOG_ERR, "focus-in-event: window not found\n");
+        log_error(LOG_DEFAULT, "focus-in-event: window not found\n");
         archdep_vice_exit(1);
     }
 
@@ -1034,7 +1027,7 @@ static gboolean on_window_state_event(GtkWidget *widget,
 
     if (index < 0) {
         /* We should never end up here. */
-        log_error(LOG_ERR, "window-state-event: window not found\n");
+        log_error(LOG_DEFAULT, "window-state-event: window not found\n");
         archdep_vice_exit(1);
     }
 
@@ -1222,7 +1215,7 @@ video_canvas_t *ui_get_active_canvas(void)
 
     canvas = ui_resources.canvas[active_win_index];
     if (canvas == NULL) {
-        log_error(LOG_ERR, "No canvas for window %d!", active_win_index);
+        log_error(LOG_DEFAULT, "No canvas for window %d!", active_win_index);
     }
     return canvas;
 }
@@ -1622,7 +1615,7 @@ void macos_set_dock_icon_workaround(GdkPixbuf *icon)
     gbytes = g_bytes_new_take(png_buffer, png_buffer_size);
 
     if (!gbytes) {
-        log_error(LOG_ERR, "macos_set_dock_icon_workaround: failed to access icon bytes from gresource file.\n");
+        log_error(LOG_DEFAULT, "macos_set_dock_icon_workaround: failed to access icon bytes from gresource file.\n");
         return;
     }
 
@@ -1642,7 +1635,7 @@ void macos_set_dock_icon_workaround(GdkPixbuf *icon)
         OBJC_MSGSEND(id, id, SEL, id)(application, sel_getUid("setApplicationIconImage:"), logo);
         OBJC_MSGSEND(id, id, SEL)(logo, sel_getUid("release"));
     } else {
-        log_error(LOG_ERR, "macos_set_dock_icon_workaround: failed to initialise image from resource");
+        log_error(LOG_DEFAULT, "macos_set_dock_icon_workaround: failed to initialise image from resource");
     }
 }
 
@@ -1795,6 +1788,9 @@ void ui_create_main_window(video_canvas_t *canvas)
     }
 
     new_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+    /* Set the gravity so that gtk doesn't over-compensate for the
+     * window's border width when saving/restoring its position. */
+    gtk_window_set_gravity(GTK_WINDOW(new_window), GDK_GRAVITY_STATIC);
     /* this needs to be here to make the menus with accelerators work */
     vhk_gtk_init_accelerators(new_window);
 
@@ -1838,11 +1834,11 @@ void ui_create_main_window(video_canvas_t *canvas)
         target_window = identify_canvas_func(canvas);
     }
     if (target_window < 0) {
-        log_error(LOG_ERR, "ui_create_main_window: canvas not identified!\n");
+        log_error(LOG_DEFAULT, "ui_create_main_window: canvas not identified!\n");
         archdep_vice_exit(1);
     }
     if (ui_resources.window_widget[target_window] != NULL) {
-        log_error(LOG_ERR, "ui_create_main_window: existing window recreated??\n");
+        log_error(LOG_DEFAULT, "ui_create_main_window: existing window recreated??\n");
         archdep_vice_exit(1);
     }
 
@@ -2160,13 +2156,13 @@ int ui_init(void)
     }
 
     if (!uidata_init()) {
-        log_error(LOG_ERR,
+        log_error(LOG_DEFAULT,
                 "failed to initialize GResource data, don't expect much"
                 " when it comes to icons, fonts or logos.");
     }
 
     if (!archdep_register_cbmfont()) {
-        log_error(LOG_ERR, "failed to register CBM font.");
+        log_error(LOG_DEFAULT, "failed to register CBM font.");
     }
 
     /*
@@ -2183,6 +2179,12 @@ int ui_init(void)
     variant = g_variant_new("b", TRUE);
     /* floating ref is consumed here */
     g_settings_set_value(settings, "sort-directories-first", variant);
+
+    /* disable the "Recent files" crap when opening without explicitly setting
+     * a directory */
+    variant = g_variant_new("s", "cwd");
+    g_settings_set_value(settings, "startup-mode", variant);
+
     /* this should be unref'ed after use */
     g_object_unref(settings);
 
@@ -2420,9 +2422,7 @@ void ui_shutdown(void)
     cart_image_widgets_shutdown();
     settings_keyboard_widget_shutdown();
     actions_settings_shutdown();
-#ifdef HAVE_DEBUG_GTK3UI
-    rom_manager_shutdown();
-#endif
+    settings_rom_widget_shutdown();
     /* hotkeys are shut down in src/main.c */
 }
 
@@ -2510,21 +2510,16 @@ void arch_ui_activate(void)
 
 /** \brief  Error dialog handler for the threaded UI
  *
- * \param[in]   user_data   error message
+ * \param[in]   user_data   error message (allocated by VICE)
  *
- * \return  FALSE
+ * \return  \c G_SOURCE_REMOVE to only run once
  */
 static gboolean ui_error_impl(gpointer user_data)
 {
-    char *buffer = (char *)user_data;
-    GtkWidget *dialog;
-
-    dialog = vice_gtk3_message_error("VICE Error", "%s", buffer);
-    gtk_dialog_run(GTK_DIALOG(dialog));
-
-    lib_free(buffer);
-
-    return FALSE;
+    vice_gtk3_message_error(NULL, /* current emu window as parent */
+                            "VICE Error", "%s", (const char*)user_data);
+    lib_free(user_data);
+    return G_SOURCE_REMOVE;
 }
 
 
@@ -2554,15 +2549,9 @@ void ui_error(const char *format, ...)
  */
 static gboolean ui_message_impl(gpointer user_data)
 {
-    char *buffer = (char *)user_data;
-    GtkWidget *dialog;
-
-    dialog = vice_gtk3_message_info("VICE Message", "%s", buffer);
-    gtk_dialog_run(GTK_DIALOG(dialog));
-
-    lib_free(buffer);
-
-    return FALSE;
+    vice_gtk3_message_info(NULL, "VICE Message", "%s", (const char *)user_data);
+    lib_free(user_data);
+    return G_SOURCE_REMOVE;
 }
 
 
